pub struct CostChange { /* private fields */ }Expand description
A Gas counter for calculating gas consumption.
Gas cost can be increased or reduced during transition. In some situations, the total
increase amount must be bounded regardless of how large is the reduce amount. Hence, there are
two counters keep track on the both positive and negative side of the value, named deduct and reward.
The counter deduct is to be checked if it exceeds certain limit at some point, while the counter reward
is used at the end of the process to calculate the final gas cost by compensating it.
Example:
let mut change = CostChange::default(); // = 0
change += CostChange::reward(1); // = 1
change += CostChange::deduct(2); // = -1
assert_eq!(change.values().0, 1);Implementations